pub fn orgqr<T: SolverScalar>(
handle: &DnHandle,
m: i32,
n: i32,
k: i32,
a: &mut DeviceBuffer<T>,
lda: i32,
tau: &DeviceBuffer<T>,
info: &mut DeviceBuffer<i32>,
) -> Result<()>Expand description
Generate the orthogonal matrix Q from the factorization produced by
geqrf. After this, a holds the first n columns of Q.